@@ -12,9 +12,15 @@ st.set_page_config(
 
 @st.cache(suppress_st_warning=True,
           ttl=1000,
-          show_spinner=False)
-def generate(keywords, model="k2t"):
-    nlp = pipeline(model)
+          show_spinner=False,
+          allow_output_mutation=True)
+def model(model_name="k2t"):
+    pipe = pipeline(model_name)
+    return pipe
+
+
+def generate(keywords):
+    nlp = model()
     return nlp(keywords)
 
 
@@ -24,21 +30,20 @@ def display():
         '''
         *For additional questions and inquiries, please contact **Gagan Bhatia** via [LinkedIn](
         https://www.linkedin.com/in/gbhatia30/) or [Github](https://github.com/gagan3012).*
-        
-        This keyword entry method is called streamlit tags and it also built by me.
+        This keyword entry method is called [streamlit-tags]() and it also built by me.
         ''')
 
-    mt = st.slider(label="Number of Keywords you would like to enter:",
-                   min_value=1,
-                   max_value=10,
-                   value=3,
-                   step=1)
+    mt = st.number_input(label="Number of Keywords you would like to enter:",
+                         min_value=1,
+                         max_value=10,
+                         value=3,
+                         step=1)
 
-    model = st_tags(label='## Select model:',
-                    text='',
-                    value=['k2t'],
-                    maxtags=1,
-                    key='Model')
+    model_name = st_tags(label='## Select model:',
+                         text='',
+                         value=['k2t'],
+                         maxtags=1,
+                         key='Model')
 
     keywords = st_tags(label='## Enter Keywords:',
                        text='Press enter to add more',
@@ -48,8 +53,7 @@ def display():
 
     if st.button("Generate text"):
         with st.spinner("Connecting the Dots..."):
-            text = generate(keywords=keywords,
-                            model=model[0])
+            text = generate(keywords=keywords)
         st.write("# Generated Sentence:")
         st.write("## {}".format(text))
 
